from matplotlib import pyplot as plt
from math import pi
import numpy
import pickle
from two_arm_utils import TwoArmController


def get_plans():
    tac = TwoArmController()

    ##### Collecting 3 trajectories generated by MoveIt
    # 1. Short path collision free
    # 2. Long path collision free
    # 3. Long path around static collision object
    #####

    home = [0, -pi/2, 0, 0, 0, 0]

    def getplan(start_j, end_j, otherarm):
        tac.go_to_joint(start_j,1)
        tac.go_to_joint(otherarm,2)

        tac.arm1.set_joint_value_target(end_j)
        success, plan, tim, _ = tac.arm1.plan()
        return plan

    ### 1
    start_j1 = [-0.00968, -0.94221, 2.033211, -2.66105, -1.57006, -0.00966]
    end_j1 = [0.31649, -0.8481, 1.81472, -2.5368, -1.5697, 0.31643]
    plan1 = getplan(start_j1, end_j1, home)

    ### 2
    start_j2 = [0.3559, -0.8091, 2.04597, -2.8070, -1.5694, 0.35605]
    end_j2 = [-0.9795, -0.7590, 1.83627, -2.6468, -1.5712, -0.9794]
    plan2 = getplan(start_j2, end_j2, home)

    ### 3
    start_j3 = start_j2
    end_j3 = end_j2
    otherarm = [-2.9722, -2.5331, -1.4027, 2.36456, -1.5716, -2.9723]
    plan3 = getplan(start_j3, end_j3, otherarm)
    return plan1, plan2, plan3


def plot_plan(plan):
    """
    MoveIt Robot Trajectory message plotted

    joint angle vs time for all 6 joint angles
    """

    #unroll
    joints = [[],[],[],[],[],[]]
    time = []
    for p in plan.joint_trajectory.points:
        for i,j in enumerate(p.positions):
            joints[i].append(j)
        time.append(p.time_from_start.to_sec())

    # do the plots
    fig, ax = plt.subplots()

    for i in range(len(joints)):
        ax.plot(time, joints[i], label="joint " + str(i))
    ax.set(xlabel='Time (s)',
            ylabel='Joint Angle (radians)',
            title='Joint angles over time'
            )
    plt.legend()
    ax.grid()
    plt.show()




if __name__ == "__main__":
    ## Generate plans
    #with open("testplans.pkl", 'wb') as f:
    #    pickle.dump(get_plans(),f)

    ## load previously generated plans
    with open("testplans.pkl", 'rb') as f:
        plan1, plan2, plan3 = pickle.load(f)

    ## Do plotting here
    plot_plan(plan3)
